.. _Urls:

Urls
====

URL is user friendly based on a unique slug. Valid slug characters are alphanumerics with hyphen as words joining.

For instance: `<http://mysmile.com.ua/en/about-company.html>`_
